@@ -8,19 +8,19 @@
 ; Definitions
 
 (alias
-  name: (identifier) @local.definition)
+  name: (identifier) @local.definition.variable)
 
 (assignment
-  name: (identifier) @local.definition)
+  name: (identifier) @local.definition.variable)
 
 (mod
-  name: (identifier) @local.definition)
+  name: (identifier) @local.definition.namespace)
 
 (recipe_parameter
-  name: (identifier) @local.definition)
+  name: (identifier) @local.definition.variable.parameter)
 
 (recipe
-  name: (identifier) @local.definition)
+  name: (identifier) @local.definition.function)
 
 ; References
 
